@@ -201,7 +201,7 @@ static int cisco_card_save_config(vm_instance_t *vm,struct cisco_card *card,
    struct cisco_nio_binding *nb;
 
    if (card != NULL) {
-      fprintf(fd,"vm add_slot_binding %s %u %u %s\n",
+      fprintf(fd,"vm slot_add_binding %s %u %u %s\n",
               vm->name,card->slot_id,card->subslot_id,card->dev_type);
 
       for(nb=card->nio_list;nb;nb=nb->next) {
@@ -932,16 +932,6 @@ int vm_slot_cmd_add_nio(vm_instance_t *vm,char *str)
                                      tokens[4],atoi(tokens[5]));
          break;
 
-      case NETIO_TYPE_MCAST:
-         if (count != 5) {
-            vm_error(vm,"invalid number of arguments for Multicast NIO '%s'\n",
-                     str);
-            goto done;
-         }
-
-         nio = netio_desc_create_mcast(nio_name,tokens[3],atoi(tokens[4]));
-         break;
-
       case NETIO_TYPE_TCP_CLI:
          if (count != 5) {
             vm_error(vm,"invalid number of arguments for TCP CLI NIO '%s'\n",
