@@ -4,7 +4,7 @@
  * Patched by Jeremy Grossmann for the GNS3 project (www.gns3.net)
  *
  * Many thanks to Nicolas Szalay for his patch
- * for the command line parsing and virtual machine 
+ * for the command line parsing and virtual machine
  * settings (RAM, ROM, NVRAM, ...)
  */
 
@@ -21,7 +21,6 @@
 #include <getopt.h>
 
 #include "dynamips.h"
-#include "gen_uuid.h"
 #include "cpu.h"
 #include "vm.h"
 
@@ -74,7 +73,7 @@ const char *os_name = STRINGIFY(OSNAME);
 const char *sw_version = DYNAMIPS_VERSION"-"JIT_ARCH;
 
 /* Software version tag */
-const char *sw_version_tag = "2014092320";
+const char *sw_version_tag = "2023010200";
 
 /* Hypervisor */
 int hypervisor_mode = 0;
@@ -94,6 +93,9 @@ static char *default_platform = "7200";
 /* Binding address (NULL means any or 0.0.0.0) */
 char *binding_addr = NULL;
 
+/* Console (vtty tcp) binding address (NULL means any or 0.0.0.0) */
+char *console_binding_addr = NULL;
+
 /* Generic signal handler */
 void signal_gen_handler(int sig)
 {
@@ -111,7 +113,7 @@ void signal_gen_handler(int sig)
       case SIGPIPE:
          fprintf(stderr,"Error: unwanted SIGPIPE.\n");
          break;
-		 
+
       case SIGINT:
          /* CTRL+C has been pressed */
          if (hypervisor_mode)
@@ -184,7 +186,7 @@ static void close_log_file(void)
 static void show_usage(vm_instance_t *vm,int argc,char *argv[])
 {
    printf("Usage: %s [options] <ios_image>\n\n",argv[0]);
-   
+
    printf("Available options:\n"
           "  -H [<ip_address>:]<tcp_port> : Run in hypervisor mode\n\n"
           "  -P <platform>      : Platform to emulate (7200, 3600, "
@@ -228,6 +230,7 @@ static void show_usage(vm_instance_t *vm,int argc,char *argv[])
           "  --noctrl           : Disable ctrl+] monitor console\n"
           "  --notelnetmsg      : Disable message when using tcp console/aux\n"
           "  --filepid filename : Store dynamips pid in a file\n"
+          "  --console-binding-addr: binding address for tcp console/aux\n"
           "\n",
           LOGFILE_DEFAULT_NAME,VM_TIMER_IRQ_CHECK_ITV,
           vm->ram_size,vm->rom_size,vm->nvram_size,vm->conf_reg_setup,
@@ -290,7 +293,7 @@ static void show_usage(vm_instance_t *vm,int argc,char *argv[])
 
    /* Show possible slot drivers */
    vm_slot_show_drivers(vm);
-   
+
    /* Show the possible NETIO types */
    netio_show_types();
 }
@@ -372,6 +375,7 @@ static struct option cmd_line_lopts[] = {
    { "filepid"    , 1, NULL, OPT_FILEPID },
    { "startup-config", 1, NULL, OPT_STARTUP_CONFIG_FILE },
    { "private-config", 1, NULL, OPT_PRIVATE_CONFIG_FILE },
+   { "console-binding-addr", 1, NULL, OPT_CONSOLE_BINDING_ADDR },
    { NULL         , 0, NULL, 0 },
 };
 
@@ -382,7 +386,7 @@ static vm_instance_t *cli_create_instance(char *name,char *platform_name,
    vm_instance_t *vm;
 
    vm = vm_create_instance(name,instance_id,platform_name);
-  
+
    if (vm == NULL) {
       fprintf(stderr,"%s: unable to create instance %s!\n",platform_name,name);
       return NULL;
@@ -394,7 +398,7 @@ static vm_instance_t *cli_create_instance(char *name,char *platform_name,
 /* Parse the command line */
 static int parse_std_cmd_line(int argc,char *argv[])
 {
-   char *options_list = 
+   char *options_list =
       "r:o:n:c:m:l:C:i:jt:p:s:k:T:U:A:B:a:f:E:b:S:R:M:eXP:N:G:g:L:I:";
    vm_platform_t *platform;
    vm_instance_t *vm = NULL;
@@ -428,12 +432,12 @@ static int parse_std_cmd_line(int argc,char *argv[])
       goto exit_failure;
 
    opterr = 0;
-   
+
    vtty_set_ctrlhandler(1); /* By default allow ctrl ] */
    vtty_set_telnetmsg(1);   /* By default allow telnet message */
 
    while((option = getopt_long(argc,argv,options_list,
-                               cmd_line_lopts,NULL)) != -1) 
+                               cmd_line_lopts,NULL)) != -1)
    {
       switch(option)
       {
@@ -499,12 +503,18 @@ static int parse_std_cmd_line(int argc,char *argv[])
             vm_ios_set_config(vm,vm->ios_startup_config,optarg);
             break;
 
+         /* Global console (vtty tcp) binding address */
+         case OPT_CONSOLE_BINDING_ADDR:
+            console_binding_addr = strdup(optarg);
+            printf("Console binding address set to %s\n", console_binding_addr);
+            break;
+
          /* Use physical memory to emulate RAM (no-mapped file) */
          case 'X':
             vm->ram_mmap = 0;
             break;
 
-         /* Use a ghost file to simulate RAM */           
+         /* Use a ghost file to simulate RAM */
          case 'G':
             free(vm->ghost_ram_filename);
             vm->ghost_ram_filename = strdup(optarg);
@@ -542,7 +552,7 @@ static int parse_std_cmd_line(int argc,char *argv[])
               printf("Unable to save to %s.\n",optarg);
             }
             break;
-			
+
          /* Idle PC */
          case OPT_IDLE_PC:
             vm->idle_pc = strtoull(optarg,NULL,0);
@@ -669,7 +679,7 @@ static int parse_std_cmd_line(int argc,char *argv[])
          case 'e':
             gen_eth_show_dev_list();
             goto exit_success;
-#endif            
+#endif
 
          /* Load plugin (already handled) */
          case 'L':
@@ -697,7 +707,7 @@ static int parse_std_cmd_line(int argc,char *argv[])
       /* setting IOS image file	*/
       vm_ios_set_image(vm,argv[optind]);
       printf("IOS image file: %s\n\n",vm->ios_image);
-   } else { 
+   } else {
       /* IOS missing */
       fprintf(stderr,"Please specify an IOS image filename\n");
       show_usage(vm,argc,argv);
@@ -723,8 +733,8 @@ exit_failure:
    return(-1);
 }
 
-/* 
- * Run in hypervisor mode with a config file if the "-H" option 
+/*
+ * Run in hypervisor mode with a config file if the "-H" option
  * is present in command line.
  */
 static int run_hypervisor(int argc,char *argv[])
@@ -732,7 +742,7 @@ static int run_hypervisor(int argc,char *argv[])
    char *options_list = "H:l:hN:L:";
    int i,option;
    char *index;
-   size_t len;  
+   size_t len;
    FILE *pid_file = NULL; // For saving the pid if requested
 
    vtty_set_ctrlhandler(1); /* By default allow ctrl ] */
@@ -804,7 +814,7 @@ static int run_hypervisor(int argc,char *argv[])
 
          case OPT_NOTELMSG:
             vtty_set_telnetmsg(0); /* disable telnet greeting */
-            printf("Prevent telnet message on AUX/CONSOLE connecte.\n");
+            printf("Prevent telnet message on AUX/CONSOLE connect.\n");
             break;
 
          case OPT_FILEPID:
@@ -816,6 +826,12 @@ static int run_hypervisor(int argc,char *argv[])
             }
             break;
 
+         /* Global console (vtty tcp) binding address */
+         case OPT_CONSOLE_BINDING_ADDR:
+            console_binding_addr = strdup(optarg);
+            printf("Console binding address set to %s\n", console_binding_addr);
+            break;
+
          /* Oops ! */
          case '?':
             //show_usage(argc,argv,VM_TYPE_C7200);
@@ -886,6 +902,10 @@ static void destroy_cmd_line_vars(void)
       free(hypervisor_ip_address);
       hypervisor_ip_address = NULL;
    }
+   if (console_binding_addr) {
+      free(console_binding_addr);
+      console_binding_addr = NULL;
+   }
 }
 
 int main(int argc,char *argv[])
@@ -907,8 +927,6 @@ int main(int argc,char *argv[])
    printf("Copyright (c) 2005-2011 Christophe Fillot.\n");
    printf("Build date: %s %s\n\n",__DATE__,__TIME__);
 
-   gen_uuid_init();
-
    /* Register platforms */
    register_default_platforms();
 
@@ -917,7 +935,7 @@ int main(int argc,char *argv[])
 
    /* Initialize object registry */
    registry_init();
-   
+
    /* Initialize ATM module (for HEC checksums) */
    atm_init();
 
@@ -932,7 +950,7 @@ int main(int argc,char *argv[])
 
    /* Initialize VTTY code */
    vtty_init();
-   
+
    /* Parse standard command line */
    atexit(destroy_cmd_line_vars);
    if (!run_hypervisor(argc,argv))
@@ -950,7 +968,7 @@ int main(int argc,char *argv[])
    mips64_exec_create_ilt();
    ppc32_jit_create_ilt();
    ppc32_exec_create_ilt();
-   
+
    setup_signals();
 
    if (!hypervisor_mode) {
