@@ -278,7 +278,7 @@ int udp_connect(int local_port,char *remote_host,int remote_port)
 {
    struct addrinfo hints,*res,*res0;
    struct sockaddr_storage st;
-   int error, sck = -1;
+   int error, sck = -1, yes = 1;
    char port_str[20];
 
    memset(&hints,0,sizeof(hints));
@@ -333,6 +333,7 @@ int udp_connect(int local_port,char *remote_host,int remote_port)
       }
 
       /* try to connect to remote host */
+      setsockopt(sck, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes));
       if (!bind(sck,(struct sockaddr *)&st,res->ai_addrlen) &&
           !connect(sck,res->ai_addr,res->ai_addrlen))
          break;
@@ -342,6 +343,10 @@ int udp_connect(int local_port,char *remote_host,int remote_port)
    }
 
    freeaddrinfo(res0);
+
+   if (sck >= 0 && m_fd_set_non_block(sck) < 0)
+      perror("Warning: udp_connect: m_fd_set_non_block");
+
    return(sck);
 }
 #else
@@ -355,7 +360,7 @@ int udp_connect(int local_port,char *remote_host,int remote_port)
 { 
    struct sockaddr_in sin;
    struct hostent *hp;
-   int sck;
+   int sck, yes = 1;
 
    if (!(hp = gethostbyname(remote_host))) {
       fprintf(stderr,"udp_connect: unable to resolve '%s'\n",remote_host);
@@ -371,7 +376,8 @@ int udp_connect(int local_port,char *remote_host,int remote_port)
    memset(&sin,0,sizeof(sin));
    sin.sin_family = PF_INET;
    sin.sin_port = htons(local_port);
-   
+
+   setsockopt(sck, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes));
    if (bind(sck,(struct sockaddr *)&sin,sizeof(sin)) < 0) {
       perror("udp_connect: bind");
       close(sck);
@@ -387,8 +393,12 @@ int udp_connect(int local_port,char *remote_host,int remote_port)
    if (connect(sck,(struct sockaddr *)&sin,sizeof(sin)) < 0) {
       perror("udp_connect: connect");
       close(sck);
+      return(-1);
    }
 
+   if (m_fd_set_non_block(sck) < 0)
+      perror("Warning: udp_connect: m_fd_set_non_block");
+
    return(sck);
 }
 #endif /* HAS_RFC2553 */
@@ -700,185 +710,6 @@ int udp_listen_range(char *ip_addr,int port_start,int port_end,int *port)
    return(ip_listen_range(ip_addr,port_start,port_end,port,SOCK_DGRAM));
 }
 
-#if HAS_RFC2553
-#if !defined(IPV6_JOIN_GROUP) && defined(IPV6_ADD_MEMBERSHIP)
-// cygwin doesn't have IPV6_JOIN_GROUP anymore (is copy of IPV6_ADD_MEMBERSHIP)
-#define IPV6_JOIN_GROUP IPV6_ADD_MEMBERSHIP
-#endif
-/* Open a multicast socket */
-int udp_mcast_socket(char *mcast_group,int mcast_port,
-                     struct sockaddr *sa,int *sa_len)
-{
-   struct addrinfo hints,*res,*res0;
-   struct sockaddr_storage st;
-   int error, sck = -1, tmp = 1;
-   char port_str[20];
-
-   memset(&hints,0,sizeof(hints));
-   hints.ai_family = PF_UNSPEC;
-   hints.ai_socktype = SOCK_DGRAM;
-
-   snprintf(port_str,sizeof(port_str),"%d",mcast_port);
-
-   if ((error = getaddrinfo(mcast_group,port_str,&hints,&res0)) != 0) {
-      fprintf(stderr,"%s\n",gai_strerror(error));
-      return(-1);
-   }
-
-   for(res=res0;res;res=res->ai_next)
-   {
-      /* We want only IPv4 or IPv6 */
-      if ((res->ai_family != PF_INET) && (res->ai_family != PF_INET6))
-         continue;
-
-      /* create new socket */
-      if ((sck = socket(res->ai_family,SOCK_DGRAM,res->ai_protocol)) < 0) {
-         perror("udp_mcast_socket: socket");
-         continue;
-      }
-
-#ifdef SO_REUSEPORT
-      setsockopt(sck,SOL_SOCKET,SO_REUSEPORT,&tmp,sizeof(tmp));
-#endif
-      setsockopt(sck,SOL_SOCKET,SO_REUSEADDR,&tmp,sizeof(tmp));
-
-      /* bind to the mcast port */
-      memset(&st,0,sizeof(st));
-      
-      switch(res->ai_family) {
-         case PF_INET: {
-            struct sockaddr_in *sin = (struct sockaddr_in *)&st;
-            struct ip_mreq mreq;
-
-            /* prepare the bind() call */
-            sin->sin_family = PF_INET;
-            sin->sin_port = htons(mcast_port);
-            sin->sin_addr = ((struct sockaddr_in *)res->ai_addr)->sin_addr;
-
-            /* try to join the multicast group */
-            memset(&mreq,0,sizeof(mreq));
-            mreq.imr_multiaddr = sin->sin_addr;
-
-            if (setsockopt(sck,IPPROTO_IP,IP_ADD_MEMBERSHIP,
-                           &mreq,sizeof(mreq)) == -1) 
-               goto next_try;
-
-            break;
-         }
-
-         case PF_INET6: {
-            struct sockaddr_in6 *sin6 = (struct sockaddr_in6 *)&st;
-            struct ipv6_mreq mreq;
-
-            /* prepare the bind() call */
-#ifdef SIN6_LEN
-            sin6->sin6_len = res->ai_addrlen;
-#endif
-            sin6->sin6_family = PF_INET6;
-            sin6->sin6_port = htons(mcast_port);
-            sin6->sin6_addr = ((struct sockaddr_in6 *)res->ai_addr)->sin6_addr;
-
-            /* try to join the multicast group */
-            memset(&mreq,0,sizeof(mreq));
-            mreq.ipv6mr_multiaddr = sin6->sin6_addr;
-
-            if (setsockopt(sck,IPPROTO_IPV6,IPV6_JOIN_GROUP,
-                           &mreq,sizeof(mreq)) == -1)
-               goto next_try;
-
-            break;
-         }
-
-         default:
-            /* shouldn't happen */
-            goto next_try;
-      }
-
-      if (!bind(sck,(struct sockaddr *)&st,res->ai_addrlen)) {
-         /* Prepare info for sendto() */
-         memcpy(sa,res->ai_addr,res->ai_addrlen);
-         *sa_len = res->ai_addrlen;
-         break;
-      }
-
-   next_try:
-      close(sck);
-      sck = -1;
-   }
-
-   freeaddrinfo(res0);
-   return(sck);
-}
-#else
-int udp_mcast_socket(char *mcast_group,int mcast_port,
-                     struct sockaddr *sa,int *sa_len)
-{
-   struct sockaddr_in sin;
-   struct ip_mreq mreq;
-   struct hostent *hp;
-   int sck,tmp = 1;
-
-   if (!(hp = gethostbyname(mcast_group))) {
-      fprintf(stderr,"udp_mcast_connect: unable to resolve '%s'\n",
-              mcast_group);
-      return(-1);
-   }
-
-   if ((sck = socket(AF_INET,SOCK_DGRAM,0)) < 0) {
-      perror("udp_mcast_socket: socket");
-      return(-1);
-   }
-
-   /* Bind multicast port */
-#ifdef SO_REUSEPORT
-   setsockopt(sck,SOL_SOCKET,SO_REUSEPORT,&tmp,sizeof(tmp));
-#endif
-   setsockopt(sck,SOL_SOCKET,SO_REUSEADDR,&tmp,sizeof(tmp));
-
-   memset(&sin,0,sizeof(sin));
-   sin.sin_family = PF_INET;
-   sin.sin_port = htons(mcast_port);
-   memcpy(&sin.sin_addr,hp->h_addr_list[0],sizeof(struct in_addr));
-
-   if (bind(sck,(struct sockaddr *)&sin,sizeof(sin)) < 0) {
-      perror("udp_mcast_socket: bind");
-      goto error;
-   }
-
-   /* Join the IP Multicast group */
-   memset(&mreq,0,sizeof(mreq));
-   mreq.imr_multiaddr = sin.sin_addr;
-   
-   if (setsockopt(sck,IPPROTO_IP,IP_ADD_MEMBERSHIP,&mreq,sizeof(mreq)) == -1) {
-      perror("udp_mcast_socket: setsockopt");
-      goto error;
-   }
-
-   /* Prepare info for sendto() */
-   memset(&sin,0,sizeof(sin));
-   sin.sin_family = PF_INET;
-   sin.sin_port = htons(mcast_port);
-   sin.sin_addr = mreq.imr_multiaddr;
-   memcpy(sa,&sin,sizeof(sin));
-   *sa_len = sizeof(sin);
-
-   return(sck);
-
- error:
-   close(sck);
-   return(-1);
-}
-#endif
-
-/* Set TTL for a multicast socket */
-int udp_mcast_set_ttl(int sck,int ttl)
-{
-   setsockopt(sck,IPPROTO_IP,IP_MULTICAST_TTL,&ttl,sizeof(ttl));
-#if HAS_RFC2553
-   setsockopt(sck,IPPROTO_IPV6,IPV6_MULTICAST_HOPS,&ttl,sizeof(ttl));
-#endif
-   return(0);
-}
 
 /* 
  * ISL rewrite.
