@@ -16,7 +16,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 
-#define N_IP_ADDR_LEN   4 
+#define N_IP_ADDR_LEN   4
 #define N_IP_ADDR_BITS  32
 
 #define N_IPV6_ADDR_LEN   16
@@ -113,6 +113,7 @@ typedef struct {
 #define N_ETH_PROTO_DOT1Q    0x8100
 #define N_ETH_PROTO_DOT1Q_2  0x9100
 #define N_ETH_PROTO_DOT1Q_3  0x9200
+#define N_ETH_PROTO_DOT1Q_4  0x88A8
 #define N_ETH_PROTO_MPLS     0x8847
 #define N_ETH_PROTO_MPLS_MC  0x8848
 #define N_ETH_PROTO_LOOP     0x9000
@@ -360,13 +361,6 @@ int udp_listen_range(char *ip_addr,int port_start,int port_end,int *port);
 /* Connect an existing socket to connect to specified host */
 int ip_connect_fd(int fd,char *remote_host,int remote_port);
 
-/* Open a multicast socket */
-int udp_mcast_socket(char *mcast_group,int mcast_port,
-                     struct sockaddr *sa,int *sa_len);
-
-/* Set TTL for a multicast socket */
-int udp_mcast_set_ttl(int sck,int ttl);
-
 /* ISL rewrite */
 void cisco_isl_rewrite(m_uint8_t *pkt,m_uint32_t tot_len);
 
