@@ -253,7 +253,7 @@ static forced_inline ppc_insn_t insn_fetch(ppc32_jit_tcb_t *b)
 #define DEBUG_HREG  0
 
 /* Show register allocation status */
-_unused static void ppc32_jit_show_hreg_status(cpu_ppc_t *cpu)
+_Unused static void ppc32_jit_show_hreg_status(cpu_ppc_t *cpu)
 {    
    struct hreg_map *map;
 
@@ -465,7 +465,7 @@ struct ppc32_insn_tag *ppc32_jit_fetch_and_emit(cpu_ppc_t *cpu,
 }
 
 /* Add end of JIT block */
-_unused static void ppc32_jit_tcb_add_end(ppc32_jit_tcb_t *b)
+_Unused static void ppc32_jit_tcb_add_end(ppc32_jit_tcb_t *b)
 {
    ppc32_set_ia(&b->jit_ptr,b->start_ia+(b->ppc_trans_pos<<2));
    ppc32_jit_tcb_push_epilog(&b->jit_ptr);
@@ -757,7 +757,7 @@ static void ppc32_op_dump_opcode(jit_op_t *op)
 }
 
 /* Dump JIT operations (debugging) */
-_unused static void ppc32_op_dump(cpu_gen_t *cpu,ppc32_jit_tcb_t *b)
+_Unused static void ppc32_op_dump(cpu_gen_t *cpu,ppc32_jit_tcb_t *b)
 {
    m_uint32_t ia = b->start_ia;
    jit_op_t *op;
