@@ -156,7 +156,7 @@ static int ppc32_vmtest_init_platform(vm_instance_t *vm)
 }
 
 /* Boot the RAW image */
-_unused static int ppc32_vmtest_boot_raw(vm_instance_t *vm)
+_Unused static int ppc32_vmtest_boot_raw(vm_instance_t *vm)
 {   
    cpu_ppc_t *cpu;
 
